@@ -8,9 +8,9 @@ import (
 	"strings"
 	"time"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/regex"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 
 	"gopkg.in/ini.v1"
 )
@@ -279,11 +279,12 @@ func (g *Git) shouldDisplay() bool {
 		return false
 	}
 
-	gitdir, err := g.env.HasParentFilePath(".git")
+	gitdir, err := g.env.HasParentFilePath(".git", true)
 	if err != nil {
 		if !g.props.GetBool(FetchBareInfo, false) {
 			return false
 		}
+
 		g.realDir = g.env.Pwd()
 		bare := g.getGitCommandOutput("rev-parse", "--is-bare-repository")
 		if bare == trueStr {
@@ -291,6 +292,7 @@ func (g *Git) shouldDisplay() bool {
 			g.workingDir = g.realDir
 			return true
 		}
+
 		return false
 	}
 
@@ -336,15 +338,15 @@ func (g *Git) getBareRepoInfo() {
 }
 
 func (g *Git) setDir(dir string) {
-	dir = platform.ReplaceHomeDirPrefixWithTilde(g.env, dir) // align with template PWD
-	if g.env.GOOS() == platform.WINDOWS {
+	dir = runtime.ReplaceHomeDirPrefixWithTilde(g.env, dir) // align with template PWD
+	if g.env.GOOS() == runtime.WINDOWS {
 		g.Dir = strings.TrimSuffix(dir, `\.git`)
 		return
 	}
 	g.Dir = strings.TrimSuffix(dir, "/.git")
 }
 
-func (g *Git) hasWorktree(gitdir *platform.FileInfo) bool {
+func (g *Git) hasWorktree(gitdir *runtime.FileInfo) bool {
 	g.rootDir = gitdir.Path
 	content := g.env.FileContent(gitdir.Path)
 	content = strings.Trim(content, " \r\n")
@@ -750,6 +752,7 @@ func (g *Git) setPrettyHEADName() {
 		g.Detached = !strings.HasPrefix(HEADRef, "ref:")
 		if strings.HasPrefix(HEADRef, BRANCHPREFIX) {
 			branchName := strings.TrimPrefix(HEADRef, BRANCHPREFIX)
+			g.Ref = branchName
 			g.HEAD = fmt.Sprintf("%s%s", g.props.GetString(BranchIcon, "\uE0A0"), g.formatHEAD(branchName))
 			return
 		}
@@ -757,12 +760,14 @@ func (g *Git) setPrettyHEADName() {
 		if len(HEADRef) >= 7 {
 			g.ShortHash = HEADRef[0:7]
 			g.Hash = HEADRef[0:]
+			g.Ref = g.ShortHash
 		}
 	}
 
 	// check for tag
 	tagName := g.getGitCommandOutput("describe", "--tags", "--exact-match")
 	if len(tagName) > 0 {
+		g.Ref = tagName
 		g.HEAD = fmt.Sprintf("%s%s", g.props.GetString(TagIcon, "\uF412"), tagName)
 		return
 	}
@@ -859,12 +864,12 @@ func (g *Git) getSwitchMode(property properties.Property, gitSwitch, mode string
 
 func (g *Git) repoName() string {
 	if !g.IsWorkTree {
-		return platform.Base(g.env, g.convertToLinuxPath(g.realDir))
+		return runtime.Base(g.env, g.convertToLinuxPath(g.realDir))
 	}
 
 	ind := strings.LastIndex(g.workingDir, ".git/worktrees")
 	if ind > -1 {
-		return platform.Base(g.env, g.workingDir[:ind])
+		return runtime.Base(g.env, g.workingDir[:ind])
 	}
 
 	return ""
